.. disnake-compass documentation master file, created by
   sphinx-quickstart on Sun Jul  9 19:20:23 2023.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

disnake-compass
===============

An extension for disnake aimed at making component interactions with listeners somewhat less cumbersome.


Key features
------------
- Smoothly integrates with disnake,
- Intuitive dataclass-like syntax to declare component classes,
- Fully stateless and persistent by permanently storing state inside custom ids,
- Custom id matching, parsing, conversion and creation are all managed for you,
- Highly customisable!

Getting started
---------------
.. toctree::
   :maxdepth: 1

   installing
   Quickstart Guide <quickstart/index>
   Examples </examples/index.rst>

.. toctree::
   :maxdepth: 3
   :caption: Development
   :hidden:

   API Reference </api_ref/index.rst>
   What's New? </whats_new.rst>
   Version Guarantees </version_guarantees.rst>
